@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/clip.h $
-// $Id: clip.h 94ee9b1 2021-10-07T14:27:16+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v5.5/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/clip.h $
+// $Id: clip.h a7667b4 2022-06-16T16:48:28+02:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -87,7 +87,7 @@ clip_to_bbox(const Plane_3& plane,
   }};
 
   // description of faces of the bbox
-  constexpr std::array<int, 24> face_indices
+  static constexpr std::array<int, 24> face_indices
     { { 0, 1, 2, 3,
         2, 1, 5, 6,
         3, 2, 6, 7,
@@ -95,7 +95,7 @@ clip_to_bbox(const Plane_3& plane,
         4, 0, 3, 7,
         6, 5, 4, 7 } };
 
-  constexpr std::array<int, 24> edge_indices
+  static constexpr std::array<int, 24> edge_indices
     { { 0,  1,  2, 3,
         1,  4,  5, 6,
         2,  6,  7, 8,
@@ -504,7 +504,7 @@ generic_clip_impl(
   Ob ob(tm1, tm2, vpm1, vpm2, algo_ecm1, fid_map1, use_compact_clipper);
 
   Corefinement::Intersection_of_triangle_meshes<TriangleMesh, Vpm, Vpm2, Algo_visitor >
-    functor(tm1, tm2, vpm1, vpm2, Algo_visitor(uv,ob,ecm_in,&tm2));
+    functor(tm1, tm2, vpm1, vpm2, Algo_visitor(uv,ob,ecm_in,&tm2), &tm2);
   functor(CGAL::Emptyset_iterator(), false, true);
 }
 
@@ -513,10 +513,11 @@ generic_clip_impl(
 /**
   * \ingroup PMP_corefinement_grp
   *
-  * clips `tm` by keeping the part that is inside the volume \link coref_def_subsec bounded \endlink
-  * by `clipper`.
+  * \brief clips `tm` by keeping the part that is inside the volume \link coref_def_subsec bounded \endlink by `clipper`.
+  *
   * If `tm` is closed, the clipped part can be closed too if the named parameter `clip_volume` is set to `true`.
   * See Subsection \ref coref_clip for more details.
+  *
   * \attention With the current implementation, `clipper` will be modified (refined with the intersection with `tm`).
   *
   * \pre \link CGAL::Polygon_mesh_processing::does_self_intersect() `!CGAL::Polygon_mesh_processing::does_self_intersect(tm)` \endlink
@@ -593,15 +594,17 @@ generic_clip_impl(
   *
   * @return `true` if the output surface mesh is manifold.
   *         If `false` is returned `tm` and `clipper` are only corefined.
+  *
+  * @see `split()`
   */
 template <class TriangleMesh,
-          class NamedParameters1,
-          class NamedParameters2>
+          class NamedParameters1 = parameters::Default_named_parameters,
+          class NamedParameters2 = parameters::Default_named_parameters>
 bool
 clip(TriangleMesh& tm,
      TriangleMesh& clipper,
-     const NamedParameters1& np_tm,
-     const NamedParameters2& np_c)
+     const NamedParameters1& np_tm = parameters::default_values(),
+     const NamedParameters2& np_c = parameters::default_values())
 {
   if (parameters::choose_parameter(parameters::get_parameter(np_c, internal_np::do_not_modify), false))
   {
@@ -623,12 +626,14 @@ clip(TriangleMesh& tm,
 
 /**
   * \ingroup PMP_corefinement_grp
-  * clips `tm` by keeping the part that is on the negative side of `plane` (side opposite to its normal vector).
+  *
+  * \brief clips `tm` by keeping the part that is on the negative side of `plane` (side opposite to its normal vector).
+  *
   * If `tm` is closed, the clipped part can be closed too if the named parameter `clip_volume` is set to `true`.
   * See Subsection \ref coref_clip for more details.
   *
-  * \note In the current implementation it is not possible to set the vertex point map and the default will be used. `Plane_3` must be
-  * from the same %Kernel as the point of the vertex point map.
+  * \note `Plane_3` must be from the same %Kernel as the point of the internal vertex point map of `TriangleMesh`.
+  * \note `Plane_3` must be from the same %Kernel as the point of the vertex point map of `tm`.
   *
   * \pre \link CGAL::Polygon_mesh_processing::does_self_intersect() `!CGAL::Polygon_mesh_processing::does_self_intersect(tm)` \endlink
   *
@@ -691,21 +696,25 @@ clip(TriangleMesh& tm,
   *
   * @return `true` if the output surface mesh is manifold.
   *         If `false` is returned `tm` is only refined by the intersection with `plane`.
+  *
+  * @see `split()`
   */
 template <class TriangleMesh,
-          class NamedParameters>
+          class NamedParameters = parameters::Default_named_parameters>
 bool clip(TriangleMesh& tm,
 #ifdef DOXYGEN_RUNNING
           const Plane_3& plane,
 #else
           const typename GetGeomTraits<TriangleMesh, NamedParameters>::type::Plane_3& plane,
 #endif
-          const NamedParameters& np)
+          const NamedParameters& np = parameters::default_values())
 {
-  using parameters::get_parameter;
-  using parameters::choose_parameter;
   namespace PMP = CGAL::Polygon_mesh_processing;
-  namespace params = PMP::parameters;
+  namespace params = CGAL::parameters;
+
+  using params::get_parameter;
+  using params::choose_parameter;
+
   if(boost::begin(faces(tm))==boost::end(faces(tm))) return true;
 
   CGAL::Bbox_3 bbox = ::CGAL::Polygon_mesh_processing::bbox(tm);
@@ -717,7 +726,7 @@ bool clip(TriangleMesh& tm,
   bbox=CGAL::Bbox_3(bbox.xmin()-xd, bbox.ymin()-yd, bbox.zmin()-zd,
                     bbox.xmax()+xd, bbox.ymax()+yd, bbox.zmax()+zd);
   TriangleMesh clipper;
-  Oriented_side os = internal::clip_to_bbox(plane, bbox, clipper, parameters::all_default());
+  Oriented_side os = internal::clip_to_bbox(plane, bbox, clipper, parameters::default_values());
   switch(os)
   {
     case ON_NEGATIVE_SIDE:
@@ -735,12 +744,15 @@ bool clip(TriangleMesh& tm,
 
 /**
   * \ingroup PMP_corefinement_grp
-  * clips `tm` by keeping the part that is inside `iso_cuboid`.
+  *
+  * \brief clips `tm` by keeping the part that is inside `iso_cuboid`.
+  *
   * If `tm` is closed, the clipped part can be closed too if the named parameter `clip_volume` is set to `true`.
   * See Subsection \ref coref_clip for more details.
   *
-  * \note In the current implementation it is not possible to set the vertex point map and the default will be used. `Iso_cuboid_3` must be
-  * from the same %Kernel as the point of the vertex point map.
+  * \note `Iso_cuboid_3` must be from the same %Kernel as the point of the internal vertex point map of `TriangleMesh`.
+  * \note `Iso_cuboid_3` must be from the same %Kernel as the point of the vertex point map of `tm`.
+  *
   * \pre \link CGAL::Polygon_mesh_processing::does_self_intersect() `!CGAL::Polygon_mesh_processing::does_self_intersect(tm)` \endlink
   *
   * @tparam TriangleMesh a model of `MutableFaceGraph`, `HalfedgeListGraph` and `FaceListGraph`.
@@ -794,21 +806,24 @@ bool clip(TriangleMesh& tm,
   *
   * @return `true` if the output surface mesh is manifold.
   *         If `false` is returned `tm` is only refined by the intersection with `iso_cuboid`.
+  *
+  * @see `split()`
   */
 template <class TriangleMesh,
-          class NamedParameters>
+          class NamedParameters = parameters::Default_named_parameters>
 bool clip(TriangleMesh& tm,
 #ifdef DOXYGEN_RUNNING
           const Iso_cuboid_3& iso_cuboid,
 #else
           const typename GetGeomTraits<TriangleMesh, NamedParameters>::type::Iso_cuboid_3& iso_cuboid,
 #endif
-          const NamedParameters& np)
+          const NamedParameters& np = parameters::default_values())
 {
-  using parameters::get_parameter;
-  using parameters::choose_parameter;
   namespace PMP = CGAL::Polygon_mesh_processing;
-  namespace params = PMP::parameters;
+  namespace params = CGAL::parameters;
+
+  using params::get_parameter;
+  using params::choose_parameter;
 
   if(boost::begin(faces(tm))==boost::end(faces(tm))) return true;
   TriangleMesh clipper;
@@ -824,12 +839,13 @@ bool clip(TriangleMesh& tm,
 
 /*!
   * \ingroup PMP_corefinement_grp
+  *
   * corefines `tm` and `splitter` and duplicates edges in `tm` that are on the intersection with `splitter`.
   *
   * \pre \link CGAL::Polygon_mesh_processing::does_self_intersect() `!CGAL::Polygon_mesh_processing::does_self_intersect(tm)` \endlink
   * \pre \link CGAL::Polygon_mesh_processing::does_self_intersect() `!CGAL::Polygon_mesh_processing::does_self_intersect(splitter)` \endlink
   *
-  * @tparam TriangleMesh a model of `MutableFaceGraph`, `HalfedgeListGraph` and `FaceListGraph`.
+  * @tparam TriangleMesh a model of `MutableFaceGraph`, `HalfedgeListGraph`, and `FaceListGraph`.
   *
   * @tparam NamedParameters1 a sequence of \ref bgl_namedparameters "Named Parameters"
   * @tparam NamedParameters2 a sequence of \ref bgl_namedparameters "Named Parameters"
@@ -874,14 +890,16 @@ bool clip(TriangleMesh& tm,
   *   \cgalParamNEnd
   *
   * \cgalNamedParamsEnd
+  *
+  * @see `clip()`
 */
 template <class TriangleMesh,
-          class NamedParameters1,
-          class NamedParameters2>
+          class NamedParameters1 = parameters::Default_named_parameters,
+          class NamedParameters2 = parameters::Default_named_parameters>
 void split(TriangleMesh& tm,
            TriangleMesh& splitter,
-           const NamedParameters1& np_tm,
-           const NamedParameters2& np_s)
+           const NamedParameters1& np_tm = parameters::default_values(),
+           const NamedParameters2& np_s = parameters::default_values())
 {
   namespace PMP = CGAL::Polygon_mesh_processing;
 
@@ -915,15 +933,16 @@ void split(TriangleMesh& tm,
 
 /**
   * \ingroup PMP_corefinement_grp
+  *
   * adds intersection edges of `plane` and `tm` in `tm` and duplicates those edges.
   *
-  * \note In the current implementation it is not possible to set the vertex point map and the default will be used.
+  * \note `Plane_3` must be from the same %Kernel as the point of the internal vertex point map of `TriangleMesh`.
+  * \note `Plane_3` must be from the same %Kernel as the point of the vertex point map of `tm`.
   *
   * \pre \link CGAL::Polygon_mesh_processing::does_self_intersect() `!CGAL::Polygon_mesh_processing::does_self_intersect(tm)` \endlink
   *
-  * @tparam TriangleMesh a model of `MutableFaceGraph`, `HalfedgeListGraph` and `FaceListGraph`
+  * @tparam TriangleMesh a model of `MutableFaceGraph`, `HalfedgeListGraph`, and `FaceListGraph`.
   *                      An internal property map for `CGAL::vertex_point_t` must be available.
-  *
   * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
   *
   * @param tm input triangulated surface mesh
@@ -962,21 +981,24 @@ void split(TriangleMesh& tm,
   *                     Setting this option to `true` will automatically set `throw_on_self_intersection` to `false`.}
   *   \cgalParamNEnd
   * \cgalNamedParamsEnd
+  *
+  * @see `clip()`
   */
 template <class TriangleMesh,
-          class NamedParameters>
+          class NamedParameters = parameters::Default_named_parameters>
 void split(TriangleMesh& tm,
 #ifdef DOXYGEN_RUNNING
            const Plane_3& plane,
 #else
            const typename GetGeomTraits<TriangleMesh, NamedParameters>::type::Plane_3& plane,
 #endif
-           const NamedParameters& np)
+           const NamedParameters& np = parameters::default_values())
 {
-  using parameters::get_parameter;
-  using parameters::choose_parameter;
   namespace PMP = CGAL::Polygon_mesh_processing;
-  namespace params = PMP::parameters;
+  namespace params = CGAL::parameters;
+
+  using params::get_parameter;
+  using params::choose_parameter;
 
   // create a splitter mesh for the splitting plane using an internal CGAL function
   CGAL::Bbox_3 bbox = ::CGAL::Polygon_mesh_processing::bbox(tm, np);
@@ -987,11 +1009,10 @@ void split(TriangleMesh& tm,
                       bbox.xmax()+xd, bbox.ymax()+yd, bbox.zmax()+zd);
 
   TriangleMesh splitter;
-  CGAL::Oriented_side os = PMP::internal::clip_to_bbox(plane, bbox, splitter, PMP::parameters::all_default());
+  CGAL::Oriented_side os = PMP::internal::clip_to_bbox(plane, bbox, splitter, params::default_values());
 
   if(os == CGAL::ON_ORIENTED_BOUNDARY)
   {
-
     const bool do_not_modify = choose_parameter(get_parameter(np, internal_np::allow_self_intersections), false);
     return split(tm, splitter, np, params::do_not_modify(do_not_modify));
   }
@@ -1002,16 +1023,16 @@ void split(TriangleMesh& tm,
 
 /**
   * \ingroup PMP_corefinement_grp
+  *
   * adds intersection edges of `iso_cuboid` and `tm` in `tm` and duplicates those edges.
   *
-  * \note In the current implementation it is not possible to set the vertex point map and the default will be used.
-  * \note `Iso_cuboid_3` must be from the same %Kernel as the point of the vertex point map.
+  * \note `Iso_cuboid_3` must be from the same %Kernel as the point of the internal vertex point map of `TriangleMesh`.
+  * \note `Iso_cuboid_3` must be from the same %Kernel as the point of the vertex point map of `tm`.
   *
   * \pre \link CGAL::Polygon_mesh_processing::does_self_intersect() `!CGAL::Polygon_mesh_processing::does_self_intersect(tm)` \endlink
   *
-  * @tparam TriangleMesh a model of `MutableFaceGraph`, `HalfedgeListGraph` and `FaceListGraph`
+  * @tparam TriangleMesh a model of `MutableFaceGraph`, `HalfedgeListGraph`, and `FaceListGraph`.
   *                      An internal property map for `CGAL::vertex_point_t` must be available.
-  *
   * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
   *
   * @param tm input triangulated surface mesh
@@ -1050,7 +1071,7 @@ void split(TriangleMesh& tm,
   *   \cgalParamNEnd
   *
   *   \cgalParamNBegin{use_compact_clipper}
-  *     \cgalParamDescription{if `false` the parts of `tm` coplanar with `iso_cuboid` will not be part of the output}
+  *     \cgalParamDescription{if `false`, the parts of `tm` coplanar with `iso_cuboid` will not be part of the output.}
   *     \cgalParamType{Boolean}
   *     \cgalParamDefault{`true`}
   *   \cgalParamNEnd
@@ -1063,108 +1084,36 @@ void split(TriangleMesh& tm,
   *                     Setting this option to `true` will automatically set `throw_on_self_intersection` to `false`
   *                     and `clip_volume` to `false`.}
   *   \cgalParamNEnd
-  *
   * \cgalNamedParamsEnd
+  *
+  * @see `clip()`
   */
 template <class TriangleMesh,
-          class NamedParameters>
+          class NamedParameters = parameters::Default_named_parameters>
 void split(TriangleMesh& tm,
-           #ifdef DOXYGEN_RUNNING
+#ifdef DOXYGEN_RUNNING
            const Iso_cuboid_3& iso_cuboid,
-           #else
+#else
            const typename GetGeomTraits<TriangleMesh, NamedParameters>::type::Iso_cuboid_3& iso_cuboid,
-           #endif
-           const NamedParameters& np)
+#endif
+           const NamedParameters& np = parameters::default_values())
 {
-  using parameters::get_parameter;
-  using parameters::choose_parameter;
   namespace PMP = CGAL::Polygon_mesh_processing;
-  namespace params = PMP::parameters;
+  namespace params = CGAL::parameters;
+
+  using params::get_parameter;
+  using params::choose_parameter;
+
   TriangleMesh splitter;
 
   make_hexahedron(iso_cuboid[0], iso_cuboid[1], iso_cuboid[2], iso_cuboid[3],
-      iso_cuboid[4], iso_cuboid[5], iso_cuboid[6], iso_cuboid[7],
-      splitter);
+                  iso_cuboid[4], iso_cuboid[5], iso_cuboid[6], iso_cuboid[7],
+                  splitter);
   triangulate_faces(splitter);
   const bool do_not_modify = choose_parameter(get_parameter(np, internal_np::allow_self_intersections), false);
   return split(tm, splitter, np, params::do_not_modify(do_not_modify));
 }
 
-/// \cond SKIP_IN_MANUAL
-
-// convenience overloads
-template <class TriangleMesh>
-bool clip(TriangleMesh& tm,
-          const typename GetGeomTraits<TriangleMesh>::type::Plane_3& plane)
-{
-  return clip(tm, plane, parameters::all_default());
-}
-
-// convenience overloads
-template <class TriangleMesh>
-bool clip(TriangleMesh& tm,
-          const typename GetGeomTraits<TriangleMesh>::type::Iso_cuboid_3& iso_cuboid)
-{
-  return clip(tm, iso_cuboid, parameters::all_default());
-}
-
-// convenience overload
-template <class TriangleMesh,
-          class NamedParameters1>
-bool
-clip(TriangleMesh& tm,
-     TriangleMesh& clipper,
-     const NamedParameters1& np_tm)
-{
-  return clip(tm, clipper, np_tm, parameters::all_default());
-}
-
-// convenience overload
-template <class TriangleMesh>
-bool
-clip(TriangleMesh& tm,
-     TriangleMesh& clipper)
-{
-  return clip(tm, clipper, parameters::all_default());
-}
-
-
-// convenience overload
-template <class TriangleMesh,
-          class NamedParameters1>
-void
-split(TriangleMesh& tm,
-      TriangleMesh& splitter,
-      const NamedParameters1& np_tm)
-{
-  split(tm, splitter, np_tm, parameters::all_default());
-}
-
-// convenience overload
-template <class TriangleMesh>
-void
-split(TriangleMesh& tm,
-      TriangleMesh& splitter)
-{
-  split(tm, splitter, parameters::all_default());
-}
-
-template <class TriangleMesh>
-void split(TriangleMesh& tm,
-           const typename GetGeomTraits<TriangleMesh>::type::Plane_3& plane)
-{
-   split(tm, plane, parameters::all_default());
-}
-
-template <class TriangleMesh>
-void split(TriangleMesh& tm,
-           const typename GetGeomTraits<TriangleMesh>::type::Iso_cuboid_3& iso_cuboid)
-{
-  split(tm, iso_cuboid, parameters::all_default());
-}
-
-/// \endcond
-
 } } //end of namespace CGAL::Polygon_mesh_processing
 
 #endif // CGAL_POLYGON_MESH_PROCESSING_CLIP_H
